==> haskell-tamarin-prover-export-1.8.0-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-export
version:              1.8.0
visibility:           public
id:                   tamarin-prover-export-1.8.0-EHuwr0VuC7W3kitES7pjb9
key:                  tamarin-prover-export-1.8.0-EHuwr0VuC7W3kitES7pjb9
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

category:             Theorem Provers
abi:                  822544f1de89af26fdf2086bef490a80
exposed:              True
exposed-modules:      Export RuleTranslation
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tamarin-prover-export-1.8.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tamarin-prover-export-1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.8.0-EHuwr0VuC7W3kitES7pjb9
depends:
    HStringTemplate-0.8.8-2c4ckyC6mTFABD6ZAPnhIY
    aeson-2.1.2.1-DWl9t7powqELSMlZOqEF1z
    aeson-pretty-0.8.9-3VVsVVmSRvYHqVvKeL5Esi base-4.15.1.0
    binary-0.8.8.0 bytestring-0.10.12.1 containers-0.6.4.1
    deepseq-1.4.5.0 dlist-1.0-Ge5E4TM9DngAWe8aSUgFvB exceptions-0.10.4
    fclabels-2.0.5.1-5jroVwVGWT9AYS0LTnQW1C mtl-2.2.2
    parallel-3.2.2.0-D2aleEa2VnPBr164BdKnms parsec-3.1.14.0
    process-1.6.13.2 raw-strings-qq-1.1-T2WZO3lzMGNAwXP4v5Jt
    safe-0.3.20-KQduFgbj6TCCbi4CK7DwI6
    tamarin-prover-sapic-1.8.0-2xQeREHToANET9FiK4IwK8
    tamarin-prover-term-1.8.0-9VGgVuHtfvn2MdLakF0m0a
    tamarin-prover-theory-1.8.0-2WQ22DWNQsS792iHDV34F6
    tamarin-prover-utils-1.8.0-L0mUjCTrcJv3hcurzJc9fV text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-7kew06tVyn8GtuHHGBY8V8

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-export-1.8.0-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-export.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-export
version:              1.8.0
visibility:           public
id:                   tamarin-prover-export-1.8.0-7U5wLTQjfrp88ubs6xvEJN
key:                  tamarin-prover-export-1.8.0-7U5wLTQjfrp88ubs6xvEJN
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, CISPA-Helmholtz-Centre Saarbrücken, 2019
    Charlie Jacomme, LSV, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Charlie Jacomme <charlie.jacomme@lsv.fr>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for export of processes in the Sapic calculus to the Proverif calculus

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

category:             Theorem Provers
abi:                  b4eca91087c3875cb4c49cc51beb11ff
exposed:              True
exposed-modules:      Export RuleTranslation
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tamarin-prover-export-1.8.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tamarin-prover-export-1.8.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-export
hs-libraries:         HStamarin-prover-export-1.8.0-7U5wLTQjfrp88ubs6xvEJN
depends:
    HStringTemplate-0.8.8-EOg2q7TfiU2Tk7fkDF8XS
    aeson-2.1.2.1-5RDZhERJnAA4H89g4WTdzv
    aeson-pretty-0.8.9-FgzEDhUduVt5pJqv4KNjXY base-4.15.1.0
    binary-0.8.8.0 bytestring-0.10.12.1 containers-0.6.4.1
    deepseq-1.4.5.0 dlist-1.0-Ge5E4TM9DngAWe8aSUgFvB exceptions-0.10.4
    fclabels-2.0.5.1-FsSFGrkSgOc24jsRC6J6jk mtl-2.2.2
    parallel-3.2.2.0-D2aleEa2VnPBr164BdKnms parsec-3.1.14.0
    process-1.6.13.2 raw-strings-qq-1.1-T2WZO3lzMGNAwXP4v5Jt
    safe-0.3.20-I3r2IsgJ6HyIplwNg1YNDT
    tamarin-prover-sapic-1.8.0-IhrYJ8y2A4dBG4v7dt80vG
    tamarin-prover-term-1.8.0-5Yuui5B2PnHB1YYfvCjZbL
    tamarin-prover-theory-1.8.0-9vlFamh9fDbESxVcpAGbWv
    tamarin-prover-utils-1.8.0-3iHl7F6HpZy8T0ddWXa0p1 text-1.2.5.0
    transformers-0.5.6.2 uniplate-1.6.13-CwkSwwItGJCGTH85Ej922e

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-export/html/tamarin-prover-export.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-export/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
